<?php
/**
 * Class TestSummarySubmenuPlugin.
 *
 * This plugin registers 2 submenu items pointing to dummy pages
 * - on Summary page
 * - on MantisGraph's Graph tab
 *
 * Its purpose is to test the event hooks and MantisBT navigation of these
 * submenus (highlight active item, etc)
 */

class TestSummarySubmenuPlugin extends MantisPlugin {

	function register() {
		$this->version = '1.0.0-dev';
		$this->name = 'TestSummarySubmenu';
		$this->description = 'Test plugin for Summary page and MantisGraph submenu event hooks';

		$this->requires = array(
			'MantisGraph' => '2.22.0-dev',
		);
	}

	function hooks() {
		$t_hooks = array(
			'EVENT_SUBMENU_SUMMARY' => 'new_summary',
		);

		# Avoid warning when the plugin is installed on an older version of
		# MantisBT, where MantisGraph does not register this event.
		global $g_event_cache;
		if( array_key_exists( 'EVENT_MANTISGRAPH_SUBMENU', $g_event_cache) ) {
			$t_hooks['EVENT_MANTISGRAPH_SUBMENU'] = 'new_graph';
		}

		return $t_hooks;
	}

	function new_summary() {
		return $this->menu_item( 'page1' );
	}

	function new_graph() {
		return $this->menu_item( 'page2' );
	}

	private function menu_item( $p_page ) {
		$t_param_page = explode( '/', gpc_get_string( 'page', '' ) );
		$t_plugin_page_current = end( $t_param_page );
		$t_active = $t_plugin_page_current == $p_page ? ' active' : '';

		$t_link = plugin_page( $p_page );
		$t_items[] = '<a class="btn btn-sm btn-primary btn-white ' . $t_active . '" href="' . $t_link . '">'
			. '<i class="ace-icon fa fa-pencil"></i> '
			. 'Test'
			. '</a>';

		return $t_items;
	}

}
